@@ -1,9 +1,11 @@
+import logging
 import os
 import socket
-import sys
+import time
 import uuid
 
 import pandas as pd
+import sys
 
 import pyjava.utils as utils
 from pyjava.serializers import ArrowStreamSerializer
@@ -102,7 +104,7 @@ class PythonContext(object):
         return self.output_data
 
     def __del__(self):
-        print("==clean== context")
+        logging.info("==clean== context")
         if self.log_client is not None:
             try:
                 self.log_client.close()
@@ -138,6 +140,7 @@ class PythonContext(object):
             raise Exception("input data can only be fetched once")
         self.have_fetched = True
         for items in self.input_data:
+            logging.debug(f"fetch data {items.to_pydict()}")
             yield pa.Table.from_batches([items]).to_pandas()
 
 
@@ -175,7 +178,6 @@ class RayContext(object):
         self.servers = []
         self.server_ids_in_ray = []
         self.is_setup = False
-        self.rds_list = []
         self.is_dev = utils.is_dev()
         self.is_in_mlsql = True
         self.mock_data = []
@@ -189,32 +191,36 @@ class RayContext(object):
 
     def data_servers_in_ray(self):
         import ray
+        from pyjava.rayfix import RayWrapper
+        rayw = RayWrapper()
         for server_id in self.server_ids_in_ray:
-            server = ray.experimental.get_actor(server_id)
+            server = rayw.get_actor(server_id)
             yield ray.get(server.connect_info.remote())
 
     def build_servers_in_ray(self):
-        import ray
+        from pyjava.rayfix import RayWrapper
         from pyjava.api.serve import RayDataServer
+        import ray
         buffer = []
+        rayw = RayWrapper()
         for (server_id, java_server) in zip(self.server_ids_in_ray, self.servers):
-
-            rds = RayDataServer.options(name=server_id, detached=True, max_concurrency=2).remote(server_id, java_server,
-                                                                                                 0,
-                                                                                                 java_server.timezone)
-            self.rds_list.append(rds)
+            # rds = RayDataServer.options(name=server_id, detached=True, max_concurrency=2).remote(server_id, java_server,
+            #                                                                                0,
+            #                                                                                java_server.timezone)
+            rds = rayw.options(RayDataServer, name=server_id, detached=True, max_concurrency=2).remote(server_id,
+                                                                                                       java_server,
+                                                                                                       0,
+                                                                                                       java_server.timezone)
             res = ray.get(rds.connect_info.remote())
-            if self.is_dev:
-                print("build RayDataServer server_id:{} java_server: {} servers:{}".format(server_id,
-                                                                                           str(vars(
-                                                                                               java_server)),
-                                                                                           str(vars(res))))
+            logging.debug("build ray data server server_id:{} java_server: {} servers:{}".format(server_id,
+                                                                                               str(vars(
+                                                                                                   java_server)),
+                                                                                               str(vars(res))))
             buffer.append(res)
         return buffer
 
     @staticmethod
-    def connect(_context, url):
-
+    def connect(_context, url, **kwargs):
         if isinstance(_context, PythonContext):
             context = _context
         elif isinstance(_context, dict):
@@ -230,9 +236,10 @@ class RayContext(object):
             raise Exception("context is not set")
 
         if url is not None:
-            import ray
-            ray.shutdown(exiting_interpreter=False)
-            ray.init(redis_address=url)
+            from pyjava.rayfix import RayWrapper
+            ray = RayWrapper()
+            ray.shutdown()
+            ray.init(url, **kwargs)
         return context.rayContext
 
     def setup(self, func_for_row, func_for_rows=None):
@@ -240,6 +247,8 @@ class RayContext(object):
             raise ValueError("setup can be only invoke once")
         self.is_setup = True
         import ray
+        from pyjava.rayfix import RayWrapper
+        rayw = RayWrapper()
 
         if not self.is_in_mlsql:
             if func_for_rows is not None:
@@ -256,8 +265,9 @@ class RayContext(object):
 
         buffer = []
         for server_info in self.build_servers_in_ray():
-            server = ray.experimental.get_actor(server_info.server_id)
-            buffer.append(ray.get(server.connect_info.remote()))
+            server = rayw.get_actor(server_info.server_id)
+            rci = ray.get(server.connect_info.remote())
+            buffer.append(rci)
             server.serve.remote(func_for_row, func_for_rows)
         items = [vars(server) for server in buffer]
         self.python_context.build_result(items, 1024)
